==> roccat-tools-1.0.0.tar.bz2: roccat-tools-1.0.0/libroccat/roccat_macro_thread.h <==
#ifndef __ROCCAT_MACRO_THREAD_H__
#define __ROCCAT_MACRO_THREAD_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * roccat_macro_thread is a entry coupled with a button on the right side opening a file_chooser_dialog
 */

#include "roccat/roccat.h"
#include <glib-object.h>

G_BEGIN_DECLS

#define ROCCAT_MACRO_THREAD_TYPE (roccat_macro_thread_get_type())
#define ROCCAT_MACRO_THREAD(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROCCAT_MACRO_THREAD_TYPE, RoccatMacroThread))
#define IS_ROCCAT_MACRO_THREAD(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), ROCCAT_MACRO_THREAD_TYPE))

typedef struct _RoccatMacroThread RoccatMacroThread;
typedef struct _RoccatMacroThreadPrivate RoccatMacroThreadPrivate;

struct _RoccatMacroThread {
	GObject parent;
	RoccatMacroThreadPrivate *priv;
};

GType roccat_macro_thread_get_type(void);
RoccatMacroThread *roccat_macro_thread_new(int kbd_file, int mouse_file, RoccatMacro const *macro);

gboolean roccat_macro_thread_get_running(RoccatMacroThread *roccat_macro_thread);

void roccat_macro_thread_set_cancelled(RoccatMacroThread *roccat_macro_thread);
gboolean roccat_macro_thread_get_cancelled(RoccatMacroThread *roccat_macro_thread);

void roccat_macro_thread_set_paused(RoccatMacroThread *roccat_macro_thread, gboolean value);
void roccat_macro_thread_toggle_paused(RoccatMacroThread *roccat_macro_thread);
gboolean roccat_macro_thread_get_paused(RoccatMacroThread *roccat_macro_thread);

G_END_DECLS

#endif

==> roccat-tools-1.4.0.tar.bz2: roccat-tools-1.4.0/libroccat/roccat_macro_thread.h <==
#ifndef __ROCCAT_MACRO_THREAD_H__
#define __ROCCAT_MACRO_THREAD_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat_macro.h"
#include <glib-object.h>

G_BEGIN_DECLS

#define ROCCAT_MACRO_THREAD_TYPE (roccat_macro_thread_get_type())
#define ROCCAT_MACRO_THREAD(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROCCAT_MACRO_THREAD_TYPE, RoccatMacroThread))
#define IS_ROCCAT_MACRO_THREAD(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), ROCCAT_MACRO_THREAD_TYPE))

typedef struct _RoccatMacroThread RoccatMacroThread;
typedef struct _RoccatMacroThreadPrivate RoccatMacroThreadPrivate;

struct _RoccatMacroThread {
	GObject parent;
	RoccatMacroThreadPrivate *priv;
};

GType roccat_macro_thread_get_type(void);
RoccatMacroThread *roccat_macro_thread_new(int kbd_file, int mouse_file, RoccatMacro const *macro);

gboolean roccat_macro_thread_get_running(RoccatMacroThread *roccat_macro_thread);

void roccat_macro_thread_set_cancelled(RoccatMacroThread *roccat_macro_thread);
gboolean roccat_macro_thread_get_cancelled(RoccatMacroThread *roccat_macro_thread);

void roccat_macro_thread_set_paused(RoccatMacroThread *roccat_macro_thread, gboolean value);
void roccat_macro_thread_toggle_paused(RoccatMacroThread *roccat_macro_thread);
gboolean roccat_macro_thread_get_paused(RoccatMacroThread *roccat_macro_thread);

G_END_DECLS

#endif
